import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PolicySetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#description PolicySet#description}.
     *
     * @stability stable
     */
    readonly description?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#global PolicySet#global}.
     *
     * @stability stable
     */
    readonly global?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#name PolicySet#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#organization PolicySet#organization}.
     *
     * @stability stable
     */
    readonly organization: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#policies_path PolicySet#policies_path}.
     *
     * @stability stable
     */
    readonly policiesPath?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#policy_ids PolicySet#policy_ids}.
     *
     * @stability stable
     */
    readonly policyIds?: string[];
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#slug PolicySet#slug}.
     *
     * @stability stable
     */
    readonly slug?: {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#workspace_ids PolicySet#workspace_ids}.
     *
     * @stability stable
     */
    readonly workspaceIds?: string[];
    /**
     * vcs_repo block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#vcs_repo PolicySet#vcs_repo}
     *
     * @stability stable
     */
    readonly vcsRepo?: PolicySetVcsRepo;
}
/**
 * @stability stable
 */
export interface PolicySetVcsRepo {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#branch PolicySet#branch}.
     *
     * @stability stable
     */
    readonly branch?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#identifier PolicySet#identifier}.
     *
     * @stability stable
     */
    readonly identifier: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#ingress_submodules PolicySet#ingress_submodules}.
     *
     * @stability stable
     */
    readonly ingressSubmodules?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/policy_set#oauth_token_id PolicySet#oauth_token_id}.
     *
     * @stability stable
     */
    readonly oauthTokenId: string;
}
export declare function policySetVcsRepoToTerraform(struct?: PolicySetVcsRepoOutputReference | PolicySetVcsRepo): any;
/**
 * @stability stable
 */
export declare class PolicySetVcsRepoOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): PolicySetVcsRepo | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: PolicySetVcsRepo | undefined);
    private _branch?;
    /**
     * @stability stable
     */
    get branch(): string;
    /**
     * @stability stable
     */
    set branch(value: string);
    /**
     * @stability stable
     */
    resetBranch(): void;
    /**
     * @stability stable
     */
    get branchInput(): string | undefined;
    private _identifier?;
    /**
     * @stability stable
     */
    get identifier(): string;
    /**
     * @stability stable
     */
    set identifier(value: string);
    /**
     * @stability stable
     */
    get identifierInput(): string | undefined;
    private _ingressSubmodules?;
    /**
     * @stability stable
     */
    get ingressSubmodules(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set ingressSubmodules(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetIngressSubmodules(): void;
    /**
     * @stability stable
     */
    get ingressSubmodulesInput(): boolean | cdktf.IResolvable | undefined;
    private _oauthTokenId?;
    /**
     * @stability stable
     */
    get oauthTokenId(): string;
    /**
     * @stability stable
     */
    set oauthTokenId(value: string);
    /**
     * @stability stable
     */
    get oauthTokenIdInput(): string | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/tfe/r/policy_set tfe_policy_set}.
 *
 * @stability stable
 */
export declare class PolicySet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/tfe/r/policy_set tfe_policy_set} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: PolicySetConfig);
    private _description?;
    /**
     * @stability stable
     */
    get description(): string;
    /**
     * @stability stable
     */
    set description(value: string);
    /**
     * @stability stable
     */
    resetDescription(): void;
    /**
     * @stability stable
     */
    get descriptionInput(): string | undefined;
    private _global?;
    /**
     * @stability stable
     */
    get global(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set global(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetGlobal(): void;
    /**
     * @stability stable
     */
    get globalInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _organization?;
    /**
     * @stability stable
     */
    get organization(): string;
    /**
     * @stability stable
     */
    set organization(value: string);
    /**
     * @stability stable
     */
    get organizationInput(): string | undefined;
    private _policiesPath?;
    /**
     * @stability stable
     */
    get policiesPath(): string;
    /**
     * @stability stable
     */
    set policiesPath(value: string);
    /**
     * @stability stable
     */
    resetPoliciesPath(): void;
    /**
     * @stability stable
     */
    get policiesPathInput(): string | undefined;
    private _policyIds?;
    /**
     * @stability stable
     */
    get policyIds(): string[];
    /**
     * @stability stable
     */
    set policyIds(value: string[]);
    /**
     * @stability stable
     */
    resetPolicyIds(): void;
    /**
     * @stability stable
     */
    get policyIdsInput(): string[] | undefined;
    private _slug?;
    /**
     * @stability stable
     */
    get slug(): {
        [key: string]: string;
    } | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set slug(value: {
        [key: string]: string;
    } | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSlug(): void;
    /**
     * @stability stable
     */
    get slugInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    private _workspaceIds?;
    /**
     * @stability stable
     */
    get workspaceIds(): string[];
    /**
     * @stability stable
     */
    set workspaceIds(value: string[]);
    /**
     * @stability stable
     */
    resetWorkspaceIds(): void;
    /**
     * @stability stable
     */
    get workspaceIdsInput(): string[] | undefined;
    private _vcsRepo;
    /**
     * @stability stable
     */
    get vcsRepo(): PolicySetVcsRepoOutputReference;
    /**
     * @stability stable
     */
    putVcsRepo(value: PolicySetVcsRepo): void;
    /**
     * @stability stable
     */
    resetVcsRepo(): void;
    /**
     * @stability stable
     */
    get vcsRepoInput(): PolicySetVcsRepo | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
