import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TeamConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#name Team#name}.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#organization Team#organization}.
     *
     * @stability stable
     */
    readonly organization: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#visibility Team#visibility}.
     *
     * @stability stable
     */
    readonly visibility?: string;
    /**
     * organization_access block.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#organization_access Team#organization_access}
     *
     * @stability stable
     */
    readonly organizationAccess?: TeamOrganizationAccess;
}
/**
 * @stability stable
 */
export interface TeamOrganizationAccess {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#manage_policies Team#manage_policies}.
     *
     * @stability stable
     */
    readonly managePolicies?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#manage_policy_overrides Team#manage_policy_overrides}.
     *
     * @stability stable
     */
    readonly managePolicyOverrides?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#manage_vcs_settings Team#manage_vcs_settings}.
     *
     * @stability stable
     */
    readonly manageVcsSettings?: boolean | cdktf.IResolvable;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe/r/team#manage_workspaces Team#manage_workspaces}.
     *
     * @stability stable
     */
    readonly manageWorkspaces?: boolean | cdktf.IResolvable;
}
export declare function teamOrganizationAccessToTerraform(struct?: TeamOrganizationAccessOutputReference | TeamOrganizationAccess): any;
/**
 * @stability stable
 */
export declare class TeamOrganizationAccessOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
     * @param terraformResource The parent resource.
     * @param terraformAttribute The attribute on the parent resource this class is referencing.
     * @param isSingleItem True if this is a block, false if it's a list.
     * @stability stable
     */
    constructor(terraformResource: cdktf.ITerraformResource, terraformAttribute: string, isSingleItem: boolean);
    /**
     * @stability stable
     */
    get internalValue(): TeamOrganizationAccess | undefined;
    /**
     * @stability stable
     */
    set internalValue(value: TeamOrganizationAccess | undefined);
    private _managePolicies?;
    /**
     * @stability stable
     */
    get managePolicies(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set managePolicies(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetManagePolicies(): void;
    /**
     * @stability stable
     */
    get managePoliciesInput(): boolean | cdktf.IResolvable | undefined;
    private _managePolicyOverrides?;
    /**
     * @stability stable
     */
    get managePolicyOverrides(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set managePolicyOverrides(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetManagePolicyOverrides(): void;
    /**
     * @stability stable
     */
    get managePolicyOverridesInput(): boolean | cdktf.IResolvable | undefined;
    private _manageVcsSettings?;
    /**
     * @stability stable
     */
    get manageVcsSettings(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set manageVcsSettings(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetManageVcsSettings(): void;
    /**
     * @stability stable
     */
    get manageVcsSettingsInput(): boolean | cdktf.IResolvable | undefined;
    private _manageWorkspaces?;
    /**
     * @stability stable
     */
    get manageWorkspaces(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set manageWorkspaces(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetManageWorkspaces(): void;
    /**
     * @stability stable
     */
    get manageWorkspacesInput(): boolean | cdktf.IResolvable | undefined;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/tfe/r/team tfe_team}.
 *
 * @stability stable
 */
export declare class Team extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/tfe/r/team tfe_team} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: TeamConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _organization?;
    /**
     * @stability stable
     */
    get organization(): string;
    /**
     * @stability stable
     */
    set organization(value: string);
    /**
     * @stability stable
     */
    get organizationInput(): string | undefined;
    private _visibility?;
    /**
     * @stability stable
     */
    get visibility(): string;
    /**
     * @stability stable
     */
    set visibility(value: string);
    /**
     * @stability stable
     */
    resetVisibility(): void;
    /**
     * @stability stable
     */
    get visibilityInput(): string | undefined;
    private _organizationAccess;
    /**
     * @stability stable
     */
    get organizationAccess(): TeamOrganizationAccessOutputReference;
    /**
     * @stability stable
     */
    putOrganizationAccess(value: TeamOrganizationAccess): void;
    /**
     * @stability stable
     */
    resetOrganizationAccess(): void;
    /**
     * @stability stable
     */
    get organizationAccessInput(): TeamOrganizationAccess | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
