import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface TfeProviderConfig {
    /**
     * The Terraform Enterprise hostname to connect to. Defaults to app.terraform.io.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe#hostname TfeProvider#hostname}
     *
     * @stability stable
     */
    readonly hostname?: string;
    /**
     * Whether or not to skip certificate verifications.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe#ssl_skip_verify TfeProvider#ssl_skip_verify}
     *
     * @stability stable
     */
    readonly sslSkipVerify?: boolean | cdktf.IResolvable;
    /**
     * The token used to authenticate with Terraform Enterprise.
     *
     * We recommend omitting
     * the token which can be set as credentials in the CLI config file.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe#token TfeProvider#token}
     *
     * @stability stable
     */
    readonly token?: string;
    /**
     * Alias name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/tfe#alias TfeProvider#alias}
     *
     * @stability stable
     */
    readonly alias?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/tfe tfe}.
 *
 * @stability stable
 */
export declare class TfeProvider extends cdktf.TerraformProvider {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/tfe tfe} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: TfeProviderConfig);
    private _hostname?;
    /**
     * @stability stable
     */
    get hostname(): string | undefined;
    /**
     * @stability stable
     */
    set hostname(value: string | undefined);
    /**
     * @stability stable
     */
    resetHostname(): void;
    /**
     * @stability stable
     */
    get hostnameInput(): string | undefined;
    private _sslSkipVerify?;
    /**
     * @stability stable
     */
    get sslSkipVerify(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set sslSkipVerify(value: boolean | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetSslSkipVerify(): void;
    /**
     * @stability stable
     */
    get sslSkipVerifyInput(): boolean | cdktf.IResolvable | undefined;
    private _token?;
    /**
     * @stability stable
     */
    get token(): string | undefined;
    /**
     * @stability stable
     */
    set token(value: string | undefined);
    /**
     * @stability stable
     */
    resetToken(): void;
    /**
     * @stability stable
     */
    get tokenInput(): string | undefined;
    private _alias?;
    /**
     * @stability stable
     */
    get alias(): string | undefined;
    /**
     * @stability stable
     */
    set alias(value: string | undefined);
    /**
     * @stability stable
     */
    resetAlias(): void;
    /**
     * @stability stable
     */
    get aliasInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
